@@ -6,7 +6,7 @@ use Locale::Utils::PlaceholderNamed;
 use Moo::Role;
 use namespace::autoclean;
 
-our $VERSION = '1.009';
+our $VERSION = '1.014';
 
 requires qw(
     translate
@@ -105,15 +105,15 @@ __END__
 
 =head1 NAME
 
-Locale::TextDomain::OO::Plugin::Expand::Gettext - Additional gettext methods
+Locale::TextDomain::OO::Plugin::Expand::Gettext - Additional gettext methods, prefixed with __
 
-$Id: Gettext.pm 487 2014-02-03 14:31:43Z steffenw $
+$Id: Gettext.pm 545 2014-10-30 13:23:00Z steffenw $
 
 $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/module/trunk/lib/Locale/TextDomain/OO/Plugin/Expand/Gettext.pm $
 
 =head1 VERSION
 
-1.009
+1.014
 
 =head1 DESCRIPTION
 
@@ -150,7 +150,7 @@ e.g.
     $self->expand_gettext->modifier_code(
         sub {
             my ( $value, $attribute ) = @_;
-            if ( $attribute eq 'num' ) {
+            if ( $attribute eq 'numf' ) {
                 # modify that numeric $value
                 # e.g. change 1234.56 to 1.234,56 or 1,234.56
                 ...
@@ -222,7 +222,7 @@ Plural and expand named placeholders
         count => $file_count,
     );
 
-What is the meaning of C<{count:num}> or alternative C<{count :num}>?
+=head3 What is the meaning of C<{count:num}> or alternative C<{count :num}>?
 
 That is a attribute.
 If there is such an attribute like C<:num>
@@ -233,16 +233,22 @@ Think about the attribute names.
 Too technical names are able to destroy the translation process
 by translation office stuff.
 
+For better automatic translation use the reserved attribute C<:num>
+and tag all numeric placeholders.
+
+You are allowed to set multiple attributes like C<{count :num :numf}>
+The resulting attribute string is then C<num :numf>.
+
 =head3 method __p
 
 Context
 
-    print $loc->__p (
+    print $loc->__p(
         'time', # Context
         'to',
     );
 
-    print $loc->__p (
+    print $loc->__p(
         'destination', # Context
         'to',
     );
@@ -251,7 +257,7 @@ Context
 
 Context and expand named placeholders
 
-    print $loc->__px (
+    print $loc->__px(
         'destination',
         'from {town_from} to {town_to}',
         # hash or hash_ref
@@ -263,7 +269,7 @@ Context and expand named placeholders
 
 Context and plural
 
-    print $loc->__np (
+    print $loc->__np(
         'maskulin',
         'Dear friend',
         'Dear friends',
